"-" should write to stdout, not stderr.


git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@79310 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/tools/llvm-extract/llvm-extract.cpp b/tools/llvm-extract/llvm-extract.cpp
index 608ae24..6b7846f 100644
--- a/tools/llvm-extract/llvm-extract.cpp
+++ b/tools/llvm-extract/llvm-extract.cpp
@@ -124,14 +124,14 @@
       return 1;
     }
   } else {                      // Specified stdout
-    // FIXME: errs() is not binary!
-    Out = &errs();
+    // FIXME: outs() is not binary!
+    Out = &outs();
   }
 
   Passes.add(createBitcodeWriterPass(*Out));
   Passes.run(*M.get());
 
-  if (Out != &errs())
+  if (Out != &outs())
     delete Out;
   return 0;
 }